==> webkit2gtk_2.20.1.orig.tar.xz: webkitgtk-2.20.1/Source/WebCore/platform/graphics/gpu/GPUComputeCommandEncoder.h <==
/*
 * Copyright (C) 2017 Yuichiro Kikura (y.kikura@gmail.com)
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBGPU)

#include "GPUSize.h"
#include <wtf/RefCounted.h>
#include <wtf/RefPtr.h>
#include <wtf/RetainPtr.h>

#if PLATFORM(COCOA)
OBJC_CLASS MTLComputeCommandEncoder;
#endif

namespace WebCore {
    
class GPUBuffer;
class GPUCommandBuffer;
class GPUComputePipelineState;

class GPUComputeCommandEncoder : public RefCounted<GPUComputeCommandEncoder> {
public:
    static RefPtr<GPUComputeCommandEncoder> create(GPUCommandBuffer*);
    WEBCORE_EXPORT ~GPUComputeCommandEncoder();
        
    WEBCORE_EXPORT void setComputePipelineState(GPUComputePipelineState*);
    WEBCORE_EXPORT void setBuffer(GPUBuffer*, unsigned, unsigned);
    WEBCORE_EXPORT void dispatch(GPUSize, GPUSize);
    WEBCORE_EXPORT void endEncoding();
        
#if PLATFORM(COCOA)
    WEBCORE_EXPORT MTLComputeCommandEncoder *platformComputeCommandEncoder();
#endif
        
private:
    GPUComputeCommandEncoder(GPUCommandBuffer*);
        
#if PLATFORM(COCOA)
    RetainPtr<MTLComputeCommandEncoder> m_computeCommandEncoder;
#endif
};
    
} // namespace WebCore
#endif

==> webkit2gtk_2.22.2.orig.tar.xz: webkitgtk-2.22.2/Source/WebCore/platform/graphics/gpu/GPUComputeCommandEncoder.h <==
/*
 * Copyright (C) 2017 Yuichiro Kikura (y.kikura@gmail.com)
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBGPU)

#include <wtf/RetainPtr.h>

OBJC_PROTOCOL(MTLComputeCommandEncoder);

namespace WebCore {
    
class GPUBuffer;
class GPUCommandBuffer;
class GPUComputePipelineState;

struct GPUSize;

class GPUComputeCommandEncoder {
public:
    explicit GPUComputeCommandEncoder(const GPUCommandBuffer&);
    ~GPUComputeCommandEncoder();

    void setComputePipelineState(const GPUComputePipelineState&) const;
    void setBuffer(const GPUBuffer&, unsigned, unsigned) const;
    void dispatch(GPUSize, GPUSize) const;
    void endEncoding() const;

#if USE(METAL)
private:
    RetainPtr<MTLComputeCommandEncoder> m_metal;
#endif
};
    
} // namespace WebCore

#endif
